pub enum SubPassCommand {
Pipeline(Option<CachedPipelineIndex>),
BindGroup(u32, Option<BindGroup>),
Mesh(Option<AssetId<Mesh>>),
DrawBatches(Vec<DrawCommandsBatch>),
Custom(for<'pass> fn(&'pass World, &mut RenderPassInstance<'pass>)),
}Expand description
Commands to execute in a render pass, in order. For example: set pipeline, set bind groups, draw calls, etc.
Variants
Pipeline(Option<CachedPipelineIndex>)
Set the pipeline for subsequent draw calls.
BindGroup(u32, Option<BindGroup>)
Set a bind group at the given index for subsequent draw calls.
Mesh(Option<AssetId<Mesh>>)
Set the vertex and index buffers for subsequent draw calls.
DrawBatches(Vec<DrawCommandsBatch>)
Issue draw calls with the given index and instance ranges, using the currently set pipeline and bind groups.
Custom(for<'pass> fn(&'pass World, &mut RenderPassInstance<'pass>))
Execute a custom function that has access to the render world and the render pass instance. This can be used for custom rendering logic that doesn’t fit into the other command types. This function should be written as fn _name_(world: &World, render_pass: &mut RenderPassInstance) { ... }.