pub struct PipelineManager { /* private fields */ }Expand description
Stores queued and realized pipelines plus shader cache. Provides an interface to queue pipelines for loading and query their status.
Implementations
Sourceimpl PipelineManager
impl PipelineManager
Sourcepub fn create_render_pipeline<E: Send + Sync + 'static>(
&mut self,
descriptor: RenderPipelineDescriptor,
asset: E,
) -> Result<CachedPipelineIndex, PrepareAssetError<E>>
pub fn create_render_pipeline<E: Send + Sync + 'static>( &mut self, descriptor: RenderPipelineDescriptor, asset: E, ) -> Result<CachedPipelineIndex, PrepareAssetError<E>>
Push the creation of a render pipeline to the pipeline manager queue.
Sourcepub fn create_compute_pipeline<E: Send + Sync + 'static>(
&mut self,
descriptor: ComputePipelineDescriptor,
asset: E,
) -> Result<CachedPipelineIndex, PrepareAssetError<E>>
pub fn create_compute_pipeline<E: Send + Sync + 'static>( &mut self, descriptor: ComputePipelineDescriptor, asset: E, ) -> Result<CachedPipelineIndex, PrepareAssetError<E>>
Push the creation of a compute pipeline to the pipeline manager queue.
Sourcepub fn get_pipeline(&self, id: CachedPipelineIndex) -> CachedPipelineStatus<'_>
pub fn get_pipeline(&self, id: CachedPipelineIndex) -> CachedPipelineStatus<'_>
Get the status of a pipeline from its cached index. Returns loading/ready/error state for both render and compute pipelines.