pub struct PushConstantDescriptor {
pub stages: ShaderStages,
pub offset: u32,
pub size: u32,
}Expand description
Describes a push constant that will be available to a shader. Note: the size of the push constant must be a multiple of 4 and must not exceed 128 bytes.
Fields
stages: ShaderStagesShader stages that can read the push constant.
offset: u32Byte offset from the start of the push constant buffer.
size: u32Size in bytes (multiple of 4, up to 128).