pub struct RenderPassDescDepthAttachment {
pub texture: Option<AssetId<Texture>>,
pub load: LoadOp<f32>,
pub store: StoreOp,
}Expand description
Depth attachment description for a render pass.
Fields
texture: Option<AssetId<Texture>>The texture to use as depth buffer.
load: LoadOp<f32>How to load the texture at the start of the pass (default: Load).
store: StoreOpHow to store the texture at the end of the pass (default: Store).