RenderPassInstance

Struct RenderPassInstance 

pub struct RenderPassInstance<'a> {
    pub label: String,
    /* private fields */
}
RAII wrapper over wgpu::RenderPass with guard rails to prevent draws without required state (pipeline + vertex/index buffers).

Example

use wde_wgpu::{
    buffer::Buffer,
    render_pass::RenderPass,
    render_pipeline::RenderPipeline,
};

let mut pass = RenderPassInstance::new("example", render_pass);
pass
    .set_pipeline(pipeline).unwrap()
    .set_vertex_buffer(0, vbo)
    .set_index_buffer(ibo)
    .draw_indexed(0..36, 0..1)
    .unwrap();

Supported operations include standard draws, indexed draws, and indirect versions of both. Errors are returned if mandatory state (pipeline, vertex/index buffers) is missing.

Fields

label: String

Implementations

Source

impl<'a> RenderPassInstance<'a>

pub fn new(label: &str, render_pass: RenderPass<'a>) -> RenderPassInstance<'a>

Create a new render pass.

Arguments
  • label - The label of the render pass.
  • render_pass - The render pass to create.
pub fn set_pipeline( &mut self, pipeline: &'a RenderPipeline, ) -> Result<&mut RenderPassInstance<'a>, RenderError>

Set the pipeline of the render pass. The bind groups of the pipeline are also set.

Arguments
  • pipeline - The pipeline to set.
Errors
  • RenderError::PipelineNotInitialized - The pipeline is not initialized.
pub fn set_vertex_buffer( &mut self, binding: u32, buffer: &'a Buffer, ) -> &mut RenderPassInstance<'a>

Set a vertex buffer of the render pass.

Arguments
  • binding - The binding of the vertex buffer.
  • buffer - The buffer to set.
pub fn set_index_buffer( &mut self, buffer: &'a Buffer, ) -> &mut RenderPassInstance<'a>

Set the index buffer of the render pass.

Arguments
  • buffer - The buffer to set.
pub fn set_scissor_rect( &mut self, x: u32, y: u32, width: u32, height: u32, ) -> &mut RenderPassInstance<'a>

Set the scissor rect of the render pass.

Arguments
  • x - X coordinate of the scissor rect.
  • y - Y coordinate of the scissor rect.
  • width - Width of the scissor rect.
  • height - Height of the scissor rect.
pub fn set_push_constants( &mut self, stages: ShaderStages, data: &[u8], ) -> &mut RenderPassInstance<'a>

Set push constants of the render pass.

Arguments
  • stages - The shader stages to set the push constants for.
  • data - The data to set.
pub fn set_bind_group( &mut self, binding: u32, bind_group: &'a BindGroup, ) -> &mut RenderPassInstance<'a>

Set a bind group of the render pass at a binding.

Arguments
  • binding - The binding of the bind group.
  • bind_group - The bind group to set.
pub fn draw( &mut self, vertices: Range<u32>, instances: Range<u32>, ) -> Result<(), RenderError>

Draws primitives from the active vertex buffers.

Arguments
  • vertices - Range of vertices to draw.
  • instances - Range of instances to draw.
Errors
  • RenderError::PipelineNotSet - The pipeline is not set.
pub fn draw_indexed( &mut self, indices: Range<u32>, instance_index: Range<u32>, ) -> Result<(), RenderError>

Draws primitives from the active vertex buffers as indexed triangles.

Arguments
  • indices - Range of indices to draw.
  • instance_index - Indice of the instance to draw.
Errors
  • RenderError::PipelineNotSet - The pipeline is not set.
pub fn multi_draw_indirect( &mut self, buffer: &'a Buffer, offset: u64, count: u32, ) -> Result<(), RenderError>

Draws primitives from the active vertex buffers. The draw is indirect, meaning the draw arguments are read from a buffer.

Arguments
  • buffer - The buffer to read the draw arguments from.
  • offset - The first draw argument to read.
  • count - The number of draw arguments to read.
Errors
  • RenderError::PipelineNotSet - The pipeline is not set.
  • RenderError::MissingVertexBuffer - The vertex buffer is not set.
pub fn multi_draw_indexed_indirect( &mut self, buffer: &'a Buffer, offset: u64, count: u32, ) -> Result<(), RenderError>

Draws primitives from the active vertex buffers as indexed triangles. The draw is indirect, meaning the draw arguments are read from a buffer.

Arguments
  • buffer - The buffer to read the draw arguments from.
  • offset - The first draw argument to read.
  • count - The number of draw arguments to read.
Errors
  • RenderError::PipelineNotSet - The pipeline is not set.
  • RenderError::MissingVertexBuffer - The vertex buffer is not set.
  • RenderError::MissingIndexBuffer - The index buffer is not set.
pub fn forget_lifetime(self) -> RenderPassInstance<'static>

Forgets the lifetime of the render pass. This is used to return the inner wgpu::RenderPass when needed.

pub fn into_inner(self) -> RenderPass<'a>

Consumes the render pass and returns the inner wgpu::RenderPass.