pub struct RenderPipelineAsset<P: RenderAsset + TypePath>(pub P);Expand description
Describes a render pipeline asset (used by [RenderPipelinePluginRegister]) which will be responsible of storing the render pipeline instance.
Most of the time, you will use it as a type alias for the SourceAsset of your render pipeline.
The render pipeline should derive the RenderAsset, [TypePath], Default, Clone and Debug traits, and implement the prepare function to create the render pipeline instance from the asset data.
See crate::passes for more details and examples.
Tuple Fields
0: PTrait Implementations
Sourceimpl<P: Clone + RenderAsset + TypePath> Clone for RenderPipelineAsset<P>
impl<P: Clone + RenderAsset + TypePath> Clone for RenderPipelineAsset<P>
Sourcefn clone(&self) -> RenderPipelineAsset<P>
fn clone(&self) -> RenderPipelineAsset<P>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<P: Debug + RenderAsset + TypePath> Debug for RenderPipelineAsset<P>
impl<P: Debug + RenderAsset + TypePath> Debug for RenderPipelineAsset<P>
Sourceimpl<P: Default + RenderAsset + TypePath> Default for RenderPipelineAsset<P>
impl<P: Default + RenderAsset + TypePath> Default for RenderPipelineAsset<P>
Sourcefn default() -> RenderPipelineAsset<P>
fn default() -> RenderPipelineAsset<P>
Returns the “default value” for a type. Read more
Sourceimpl<P: RenderAsset + TypePath> Display for RenderPipelineAsset<P>
impl<P: RenderAsset + TypePath> Display for RenderPipelineAsset<P>
Sourceimpl<P> TypePath for RenderPipelineAsset<P>
impl<P> TypePath for RenderPipelineAsset<P>
Sourcefn type_path() -> &'static str
fn type_path() -> &'static str
Returns the fully qualified path of the underlying type. Read more
Sourcefn short_type_path() -> &'static str
fn short_type_path() -> &'static str
Returns a short, pretty-print enabled path to the type. Read more
Sourcefn type_ident() -> Option<&'static str>
fn type_ident() -> Option<&'static str>
Sourcefn crate_name() -> Option<&'static str>
fn crate_name() -> Option<&'static str>
Sourceimpl<P: RenderAsset + TypePath> VisitAssetDependencies for RenderPipelineAsset<P>
impl<P: RenderAsset + TypePath> VisitAssetDependencies for RenderPipelineAsset<P>
fn visit_dependencies(&self, visit: &mut impl FnMut(UntypedAssetId))
impl<P: RenderAsset + TypePath> Asset for RenderPipelineAsset<P>