pub struct RenderPipelineDescriptor {Show 13 fields
pub label: &'static str,
pub vert: Option<Handle<Shader>>,
pub frag: Option<Handle<Shader>>,
pub depth: DepthDescriptor,
pub render_targets: Option<Vec<TextureFormat>>,
pub bind_group_layouts: Vec<Option<BindGroupLayout>>,
pub push_constants: Vec<PushConstantDescriptor>,
pub topology: RenderTopology,
pub cull_mode: Option<Face>,
pub fragment_blend: Option<BlendState>,
pub color_write: ColorWrites,
pub sample_count: u32,
pub vertex_buffer: bool,
}Expand description
Describes a render pipeline, including its shaders, resources and states.
Fields
label: &'static strvert: Option<Handle<Shader>>frag: Option<Handle<Shader>>depth: DepthDescriptorDepth/stencil state for the pipeline.
render_targets: Option<Vec<TextureFormat>>Formats of the render targets this pipeline will render to. If None, the pipeline will render to the swapchain format.
bind_group_layouts: Vec<Option<BindGroupLayout>>Bind group layouts describing all resource bindings.
push_constants: Vec<PushConstantDescriptor>Push constant ranges exposed to shaders.
topology: RenderTopologyPrimitive topology (default: TriangleList).
cull_mode: Option<Face>Face culling mode (default: Back). None disables culling.
fragment_blend: Option<BlendState>Blend state for the fragment shader (default: None, i.e. no blending).
color_write: ColorWritesColor write mask for fragment outputs (default: all channels). This enable you to disable writing to certain color channels.
sample_count: u32The sample count for multisampling (default: 1).
vertex_buffer: boolWhether the pipeline should expect a vertex buffer. Useful for pipelines that render fullscreen quads without vertex buffers (default: true).