pub struct RenderPipelineRegisterPlugin<P: RenderAsset + TypePath + Default> { /* private fields */ }Expand description
A plugin for registering a render pipeline asset and its preparation logic. It will also spawn an entity holding the render pipeline asset handle, preventing it from being dropped and unloaded.
To use it, simply add it to your app with the render pipeline asset type as generic parameter:
app.add_plugins(RenderPipelinePluginRegister::<MyRenderPipelineAsset>::default());The render pipeline should derive the RenderAsset, [TypePath], Default and Clone traits.
It should use the RenderPipelineAsset as its SourceAsset type.
See crate::passes for more details and examples.