BlendComponent

Type Alias BlendComponent 

pub type BlendComponent = BlendComponent;

Aliased Type

#[repr(C)]
pub struct BlendComponent { pub src_factor: BlendFactor, pub dst_factor: BlendFactor, pub operation: BlendOperation, }

Fields

src_factor: BlendFactor

Multiplier for the source, which is produced by the fragment shader.

dst_factor: BlendFactor

Multiplier for the destination, which is stored in the target.

operation: BlendOperation

The binary operation applied to the source and destination, multiplied by their respective factors.