pub type LoadOp<V> = LoadOp<V>;Expand description
Type of a load operation.
Aliased Type
#[repr(u8)]pub enum LoadOp<V> {
Clear(V),
Load = 1,
}Variants
Clear(V)
Loads the specified value for this attachment into the render pass.
On some GPU hardware (primarily mobile), “clear” is significantly cheaper because it avoids loading data from main memory into tile-local memory.
On other GPU hardware, there isn’t a significant difference.
As a result, it is recommended to use “clear” rather than “load” in cases where the initial value doesn’t matter (e.g. the render target will be cleared using a skybox).
Load = 1
Loads the existing value for this attachment into the render pass.