StoreOp

Type Alias StoreOp 

pub type StoreOp = StoreOp;
Type of a store operation.

Aliased Type

#[repr(C)]
pub enum StoreOp { Store = 0, Discard = 1, }

Variants



Store = 0

Stores the resulting value of the render pass for this attachment.



Discard = 1

Discards the resulting value of the render pass for this attachment.

The attachment will be treated as uninitialized afterwards. (If only either Depth or Stencil texture-aspects is set to Discard, the respective other texture-aspect will be preserved.)

This can be significantly faster on tile-based render hardware.

Prefer this if the attachment is not read by subsequent passes.