pub struct RenderGraph { /* private fields */ }Expand description
The render graph resource, which stores all render passes and sub-passes, their descriptions, and their execution order. This is the core of the render graph system, and is responsible for executing the render passes in the correct order with the correct attachments and commands.
To register a new render pass, use the add_pass method with a type that implements the RenderPass trait. To register a sub-pass to a render pass, use the add_sub_pass method with a type that implements the RenderSubPass trait and the parent render pass type.
Implementations
Sourceimpl RenderGraph
impl RenderGraph
Sourcepub fn add_pass<P: RenderPass + Send + Sync + 'static>(&mut self) -> &mut Self
pub fn add_pass<P: RenderPass + Send + Sync + 'static>(&mut self) -> &mut Self
Add a render pass to the graph. Passes execute in order of their IDs (lower IDs execute first).
The pass type must implement the RenderPass trait, which defines the pass’s description and execution logic.
Sourcepub fn add_sub_pass<SP: RenderSubPass + Send + Sync + 'static, P: RenderPass>(
&mut self,
) -> &mut Self
pub fn add_sub_pass<SP: RenderSubPass + Send + Sync + 'static, P: RenderPass>( &mut self, ) -> &mut Self
Add a sub-pass to a render pass in the graph. The sub-pass will be executed in the order it was added within its parent render pass.
The sub-pass type must implement the RenderSubPass trait, which defines the sub-pass’s commands and the render pass it belongs to.