RenderSubPass

Trait RenderSubPass 

pub trait RenderSubPass {
    type Params: ReadOnlySystemParam;

    // Required methods
    fn describe(
        params: &SystemParamItem<'_, '_, Self::Params>,
    ) -> RenderSubPassDesc;
    fn label() -> &'static str;
}
Core trait for all render sub-passes in the render graph. A sub-pass is a sequence of commands executed within a render pass. For example, a GBuffer pass might have one sub-pass for rendering opaque objects and another for transparent objects. The describe method defines the commands to execute in this sub-pass, which can be setting pipelines, bind groups, vertex buffers, draw calls, or even custom rendering logic. See crate::passes for more details and examples.

Required Associated Types

type Params: ReadOnlySystemParam

Required Methods

fn describe(params: &SystemParamItem<'_, '_, Self::Params>) -> RenderSubPassDesc

Describe the sub-pass commands to execute within the render pass.

fn label() -> &'static str

Return the (non-unique) label of this sub-pass, used for logging and debugging.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors